@@ -332,11 +332,12 @@ gnome_thumbnail_factory_instance_init (GnomeThumbnailFactory *factory)
   
   pthread_mutex_init (&factory->priv->lock, NULL);
 
-  _gnomeui_gconf_lazy_init ();
-
   gnome_thumbnail_factory_reread_scripts (factory);
 
   client = gconf_client_get_default ();
+  gconf_client_add_dir (client,
+			"/desktop/gnome",
+			GCONF_CLIENT_PRELOAD_NONE, NULL);
 
   priv->thumbnailers_notify = gconf_client_notify_add (client, "/desktop/gnome/thumbnailers",
 						       schedule_reread, factory, NULL,
@@ -775,6 +776,7 @@ gnome_thumbnail_factory_can_thumbnail (GnomeThumbnailFactory *factory,
 
 static char *
 expand_thumbnailing_script (const char *script,
+			    const int   size, 
 			    const char *inuri,
 			    const char *outfile)
 {
@@ -819,7 +821,7 @@ expand_thumbnailing_script (const char *script,
 	p++;
 	break;
       case 's':
-	g_string_append (str, "128");
+	g_string_append_printf (str, "%d", size);
 	p++;
 	break;
       case '%':
@@ -865,7 +867,7 @@ gnome_thumbnail_factory_generate_thumbnail (GnomeThumbnailFactory *factory,
   int width, height, size;
   double scale;
   int exit_status;
-  char tmpname[50];
+  char *tmpname;
 
   /* Doesn't access any volatile fields in factory, so it's threadsafe */
   
@@ -882,16 +884,15 @@ gnome_thumbnail_factory_generate_thumbnail (GnomeThumbnailFactory *factory,
   if (script)
     {
       int fd;
+      GError *error = NULL;
 
-      strcpy (tmpname, "/tmp/.gnome_thumbnail.XXXXXX");
-
-      fd = mkstemp(tmpname);
+      fd = g_file_open_tmp (".gnome_thumbnail.XXXXXX", &tmpname, &error);
 
       if (fd)
 	{
 	  close (fd);
 
-	  expanded_script = expand_thumbnailing_script (script, uri, tmpname);
+	  expanded_script = expand_thumbnailing_script (script, size, uri, tmpname);
 	  if (expanded_script != NULL &&
 	      g_spawn_command_line_sync (expanded_script,
 					 NULL, NULL, &exit_status, NULL) &&
@@ -903,6 +904,8 @@ gnome_thumbnail_factory_generate_thumbnail (GnomeThumbnailFactory *factory,
 	  
 	  unlink(tmpname);
 	}
+      if (tmpname)
+        g_free (tmpname);
     }
 
   /* Fall back to gdk-pixbuf */
